==> zio-aws-ec2_2.12-5.17.152.1-sources.jar: zio/aws/ec2/model/ReleaseIpamPoolAllocationRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{IpamPoolAllocationId, IpamPoolId}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class ReleaseIpamPoolAllocationRequest(
    ipamPoolId: IpamPoolId,
    cidr: String,
    ipamPoolAllocationId: IpamPoolAllocationId
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ReleaseIpamPoolAllocationRequest = {
    import ReleaseIpamPoolAllocationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ReleaseIpamPoolAllocationRequest
      .builder()
      .ipamPoolId(IpamPoolId.unwrap(ipamPoolId): java.lang.String)
      .cidr(cidr: java.lang.String)
      .ipamPoolAllocationId(
        IpamPoolAllocationId.unwrap(ipamPoolAllocationId): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ReleaseIpamPoolAllocationRequest.ReadOnly =
    zio.aws.ec2.model.ReleaseIpamPoolAllocationRequest.wrap(buildAwsValue())
}
object ReleaseIpamPoolAllocationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ReleaseIpamPoolAllocationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ReleaseIpamPoolAllocationRequest =
      zio.aws.ec2.model.ReleaseIpamPoolAllocationRequest(
        ipamPoolId,
        cidr,
        ipamPoolAllocationId
      )
    def ipamPoolId: IpamPoolId
    def cidr: String
    def ipamPoolAllocationId: IpamPoolAllocationId
    def getIpamPoolId: ZIO[Any, Nothing, IpamPoolId] = ZIO.succeed(ipamPoolId)
    def getCidr: ZIO[Any, Nothing, String] = ZIO.succeed(cidr)
    def getIpamPoolAllocationId: ZIO[Any, Nothing, IpamPoolAllocationId] =
      ZIO.succeed(ipamPoolAllocationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ReleaseIpamPoolAllocationRequest
  ) extends zio.aws.ec2.model.ReleaseIpamPoolAllocationRequest.ReadOnly {
    override val ipamPoolId: IpamPoolId =
      zio.aws.ec2.model.primitives.IpamPoolId(impl.ipamPoolId())
    override val cidr: String = impl.cidr(): String
    override val ipamPoolAllocationId: IpamPoolAllocationId =
      zio.aws.ec2.model.primitives
        .IpamPoolAllocationId(impl.ipamPoolAllocationId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ReleaseIpamPoolAllocationRequest
  ): zio.aws.ec2.model.ReleaseIpamPoolAllocationRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.12-7.21.15.7-sources.jar: zio/aws/ec2/model/ReleaseIpamPoolAllocationRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{IpamPoolAllocationId, IpamPoolId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ReleaseIpamPoolAllocationRequest(
    dryRun: Optional[Boolean] = Optional.Absent,
    ipamPoolId: IpamPoolId,
    cidr: String,
    ipamPoolAllocationId: IpamPoolAllocationId
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ReleaseIpamPoolAllocationRequest = {
    import ReleaseIpamPoolAllocationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ReleaseIpamPoolAllocationRequest
      .builder()
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .ipamPoolId(IpamPoolId.unwrap(ipamPoolId): java.lang.String)
      .cidr(cidr: java.lang.String)
      .ipamPoolAllocationId(
        IpamPoolAllocationId.unwrap(ipamPoolAllocationId): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ReleaseIpamPoolAllocationRequest.ReadOnly =
    zio.aws.ec2.model.ReleaseIpamPoolAllocationRequest.wrap(buildAwsValue())
}
object ReleaseIpamPoolAllocationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ReleaseIpamPoolAllocationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ReleaseIpamPoolAllocationRequest =
      zio.aws.ec2.model.ReleaseIpamPoolAllocationRequest(
        dryRun.map(value => value),
        ipamPoolId,
        cidr,
        ipamPoolAllocationId
      )
    def dryRun: Optional[Boolean]
    def ipamPoolId: IpamPoolId
    def cidr: String
    def ipamPoolAllocationId: IpamPoolAllocationId
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
    def getIpamPoolId: ZIO[Any, Nothing, IpamPoolId] = ZIO.succeed(ipamPoolId)
    def getCidr: ZIO[Any, Nothing, String] = ZIO.succeed(cidr)
    def getIpamPoolAllocationId: ZIO[Any, Nothing, IpamPoolAllocationId] =
      ZIO.succeed(ipamPoolAllocationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ReleaseIpamPoolAllocationRequest
  ) extends zio.aws.ec2.model.ReleaseIpamPoolAllocationRequest.ReadOnly {
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
    override val ipamPoolId: IpamPoolId =
      zio.aws.ec2.model.primitives.IpamPoolId(impl.ipamPoolId())
    override val cidr: String = impl.cidr(): String
    override val ipamPoolAllocationId: IpamPoolAllocationId =
      zio.aws.ec2.model.primitives
        .IpamPoolAllocationId(impl.ipamPoolAllocationId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ReleaseIpamPoolAllocationRequest
  ): zio.aws.ec2.model.ReleaseIpamPoolAllocationRequest.ReadOnly = new Wrapper(
    impl
  )
}
